![Datoso](https://github.com/laromicas/datoso/blob/master/bearlogo.png)

# Datoso Seed MegaDrive Enhanced

Datoso is a WIP Python command line tool to download and organize your Dat Roms.
As today the tool supports dat-omatic, redump, and translated-english dats.
It merges all the dats in a tree folder structure thought to use with Emulators rather than dats.
The dat file format must be compatible with [ROMVault](https://www.romvault.com/).

MegaDrive - Genesis Enhanced Roms

## Installation

Datoso requires python 3.10+.

Use pip (recommended to use a virtual environment):
If you only need this plugin you can install it directly

``` bash
pip install datoso_seed_md_enhanced

```

## Usage

Check [Datoso](https://github.com/laromicas/datoso) for usage.


## TODO

-   Tests

## Contributing

Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.
Please make sure to update tests as appropriate.

## License

[MIT](https://choosealicense.com/licenses/mit/)
